@@ -36,6 +36,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudfront
@@ -64,6 +66,10 @@ class CidrAllowList:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CidrAllowList.__init__)
+            check_type(argname="argument cidr_ranges", value=cidr_ranges, expected_type=type_hints["cidr_ranges"])
+            check_type(argname="argument cidr_type", value=cidr_type, expected_type=type_hints["cidr_type"])
         self._values: typing.Dict[str, typing.Any] = {
             "cidr_ranges": cidr_ranges,
             "cidr_type": cidr_type,
@@ -120,8 +126,8 @@ class CloudFrontWebAclProps:
     def __init__(
         self,
         *,
-        cidr_allow_list: typing.Optional[CidrAllowList] = None,
-        managed_rules: typing.Optional[typing.Sequence["ManagedRule"]] = None,
+        cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
+        managed_rules: typing.Optional[typing.Sequence[typing.Union["ManagedRule", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''(experimental) Properties to configure the web acl.
 
@@ -132,6 +138,10 @@ class CloudFrontWebAclProps:
         '''
         if isinstance(cidr_allow_list, dict):
             cidr_allow_list = CidrAllowList(**cidr_allow_list)
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudFrontWebAclProps.__init__)
+            check_type(argname="argument cidr_allow_list", value=cidr_allow_list, expected_type=type_hints["cidr_allow_list"])
+            check_type(argname="argument managed_rules", value=managed_rules, expected_type=type_hints["managed_rules"])
         self._values: typing.Dict[str, typing.Any] = {}
         if cidr_allow_list is not None:
             self._values["cidr_allow_list"] = cidr_allow_list
@@ -187,8 +197,8 @@ class CloudfrontWebAcl(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        cidr_allow_list: typing.Optional[CidrAllowList] = None,
-        managed_rules: typing.Optional[typing.Sequence["ManagedRule"]] = None,
+        cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
+        managed_rules: typing.Optional[typing.Sequence[typing.Union["ManagedRule", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -198,13 +208,17 @@ class CloudfrontWebAcl(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudfrontWebAcl.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontWebAclProps(
             cidr_allow_list=cidr_allow_list, managed_rules=managed_rules
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="webAclArn")
     def web_acl_arn(self) -> builtins.str:
         '''
@@ -212,7 +226,7 @@ class CloudfrontWebAcl(
         '''
         return typing.cast(builtins.str, jsii.get(self, "webAclArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="webAclId")
     def web_acl_id(self) -> builtins.str:
         '''
@@ -235,6 +249,10 @@ class ManagedRule:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ManagedRule.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument vendor", value=vendor, expected_type=type_hints["vendor"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "vendor": vendor,
@@ -302,6 +320,10 @@ class RuntimeOptions:
             const runtimeConfig = {jsonPayload: {bucketArn: s3Bucket.bucketArn}};
             new StaticWebsite(scope, 'StaticWebsite', {websiteContentPath: 'path/to/website', runtimeConfig});
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RuntimeOptions.__init__)
+            check_type(argname="argument json_payload", value=json_payload, expected_type=type_hints["json_payload"])
+            check_type(argname="argument json_file_name", value=json_file_name, expected_type=type_hints["json_file_name"])
         self._values: typing.Dict[str, typing.Any] = {
             "json_payload": json_payload,
         }
@@ -372,9 +394,9 @@ class StaticWebsite(
         website_content_path: builtins.str,
         default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
         default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        distribution_props: typing.Optional[aws_cdk.aws_cloudfront.DistributionProps] = None,
-        runtime_options: typing.Optional[RuntimeOptions] = None,
-        web_acl_props: typing.Optional[CloudFrontWebAclProps] = None,
+        distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
+        runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
+        web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
         website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
         '''
@@ -390,6 +412,10 @@ class StaticWebsite(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(StaticWebsite.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = StaticWebsiteProps(
             website_content_path=website_content_path,
             default_website_bucket_encryption=default_website_bucket_encryption,
@@ -402,7 +428,7 @@ class StaticWebsite(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="bucketDeployment")
     def bucket_deployment(self) -> aws_cdk.aws_s3_deployment.BucketDeployment:
         '''
@@ -410,7 +436,7 @@ class StaticWebsite(
         '''
         return typing.cast(aws_cdk.aws_s3_deployment.BucketDeployment, jsii.get(self, "bucketDeployment"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontDistribution")
     def cloud_front_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
         '''
@@ -418,7 +444,7 @@ class StaticWebsite(
         '''
         return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontDistribution"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="websiteBucket")
     def website_bucket(self) -> aws_cdk.aws_s3.IBucket:
         '''
@@ -457,6 +483,9 @@ class StaticWebsiteOrigin(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(StaticWebsiteOrigin.bind)
+            check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
         _options = aws_cdk.aws_cloudfront.OriginBindOptions(origin_id=origin_id)
 
         return typing.cast(aws_cdk.aws_cloudfront.OriginBindConfig, jsii.invoke(self, "bind", [_scope, _options]))
@@ -482,9 +511,9 @@ class StaticWebsiteProps:
         website_content_path: builtins.str,
         default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
         default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        distribution_props: typing.Optional[aws_cdk.aws_cloudfront.DistributionProps] = None,
-        runtime_options: typing.Optional[RuntimeOptions] = None,
-        web_acl_props: typing.Optional[CloudFrontWebAclProps] = None,
+        distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
+        runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
+        web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
         website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
         '''(experimental) Properties for configuring the StaticWebsite.
@@ -500,11 +529,20 @@ class StaticWebsiteProps:
         :stability: experimental
         '''
         if isinstance(distribution_props, dict):
-            distribution_props = aws_cdk.aws_cloudfront.DistributionProps(**distribution_props)
+            distribution_props = DistributionProps(**distribution_props)
         if isinstance(runtime_options, dict):
             runtime_options = RuntimeOptions(**runtime_options)
         if isinstance(web_acl_props, dict):
             web_acl_props = CloudFrontWebAclProps(**web_acl_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(StaticWebsiteProps.__init__)
+            check_type(argname="argument website_content_path", value=website_content_path, expected_type=type_hints["website_content_path"])
+            check_type(argname="argument default_website_bucket_encryption", value=default_website_bucket_encryption, expected_type=type_hints["default_website_bucket_encryption"])
+            check_type(argname="argument default_website_bucket_encryption_key", value=default_website_bucket_encryption_key, expected_type=type_hints["default_website_bucket_encryption_key"])
+            check_type(argname="argument distribution_props", value=distribution_props, expected_type=type_hints["distribution_props"])
+            check_type(argname="argument runtime_options", value=runtime_options, expected_type=type_hints["runtime_options"])
+            check_type(argname="argument web_acl_props", value=web_acl_props, expected_type=type_hints["web_acl_props"])
+            check_type(argname="argument website_bucket", value=website_bucket, expected_type=type_hints["website_bucket"])
         self._values: typing.Dict[str, typing.Any] = {
             "website_content_path": website_content_path,
         }
